import{d,eB as g,H as p,a as b,b as f,c as v,w as r,f as s}from"./outputWidgets.244ba1c8.js";import{B as _}from"./BaseLayout.8bb2298c.js";import{a as h}from"./asyncComputed.9805a381.js";import"./router.60675eeb.js";import"./index.bec3aec1.js";import{P as z}from"./project.9f9d482b.js";import{O as y}from"./organization.77001a16.js";import{_ as j}from"./Navbar.vue_vue_type_script_setup_true_lang.810ea952.js";import{S as I}from"./Sidebar.1f2caf94.js";import{e as w,J as O,K as C,L as B,M as k,N as L,o as P,O as $,s as E,E as M,F as N,G as S}from"./icons.a522dd78.js";import"./FormItem.e7fba2a7.js";import"./hasIn.d73516ff.js";import"./index.cf4c23b9.js";import"./record.5766e9f8.js";import"./pubsub.f74b1921.js";import"./logo.084e5d7c.js";import"./Text.fbfa9a45.js";import"./Base.2351f159.js";import"./Typography.52981f51.js";import"./index.29328ced.js";import"./index.feab3270.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new Error().stack;i&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[i]="cf94ce27-0084-4201-a087-de39087b67c8",o._sentryDebugIdIdentifier="sentry-dbid-cf94ce27-0084-4201-a087-de39087b67c8")}catch{}})();const ta=d({__name:"Project",setup(o){const c=g().params.projectId,{result:a}=h(()=>z.get(c).then(async e=>{const t=await y.get(e.organizationId);return{project:e,organization:t}})),m=p(()=>{var e,t,n,l;return((e=a.value)==null?void 0:e.organization)&&a.value.project?[{label:"My organizations",path:"/organizations"},{label:(n=(t=a.value)==null?void 0:t.organization)==null?void 0:n.name,path:`/organizations/${(l=a.value)==null?void 0:l.organization.id}`},{label:a.value.project.name,path:`/projects/${a.value.project.id}`}]:void 0}),u=p(()=>{var e;return(e=a.value)!=null&&e.project?[{name:"Project",items:[{name:"Live",path:"live",icon:w},{name:"Builds",path:"builds",icon:O},{name:"Connectors",path:"connectors",icon:C,unavailable:!a.value.organization.featureFlags.CONNECTORS_CONSOLE},{name:"Tables",path:"tables",icon:B},{name:"API Keys",path:"api-keys",icon:k},{name:"Env Vars",path:"env-vars",icon:L},{name:"Files",path:"files",icon:P},{name:"Logs",icon:$,path:"logs"},{name:"Settings",icon:E,path:"settings"}]},{name:"Organization",items:[{name:"Projects",icon:M,path:`/organizations/${a.value.project.organizationId}/projects`},{name:"Members",icon:N,path:`/organizations/${a.value.project.organizationId}/members`},{name:"Billing",icon:S,path:`/organizations/${a.value.project.organizationId}/billing`,unavailable:!0}]}]:[]});return(e,t)=>{const n=b("router-view");return f(),v(_,null,{content:r(()=>[s(n)]),navbar:r(()=>[s(j,{class:"nav",breadcrumb:m.value},null,8,["breadcrumb"])]),sidebar:r(()=>[s(I,{class:"sidebar",sections:u.value},null,8,["sections"])]),_:1})}}});export{ta as default};
//# sourceMappingURL=Project.24ffc035.js.map
