import{v as t,b as s,ev as o}from"./outputWidgets.244ba1c8.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="492a6028-fe6d-439c-a596-57d42fe2568c",e._sentryDebugIdIdentifier="sentry-dbid-492a6028-fe6d-439c-a596-57d42fe2568c")}catch{}})();const r={},a={class:"organization-settings"};function d(e,n){return s(),o("div",a,"Organization settings")}const f=t(r,[["render",d]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.f804fbfa.js.map
