import{_ as s}from"./Navbar.vue_vue_type_script_setup_true_lang.b46a23b6.js";import{K as d,P as f,L as l}from"./repository.116bfb52.js";import{d as c,b,ev as u,f as p,u as r}from"./outputWidgets.244ba1c8.js";import{u as g}from"./index.cc4549b3.js";import{a as y}from"./asyncComputed.9805a381.js";import{g as _}from"./api.438fac86.js";import"./Text.fbfa9a45.js";import"./Base.2351f159.js";import"./Typography.52981f51.js";import"./index.e7c19b0b.js";import"./Link.82df400a.js";import"./Paragraph.bffb9dac.js";import"./Title.eb85429e.js";import"./index.29328ced.js";import"./ant-design.2b0214de.js";import"./index.d38d9f1b.js";import"./Modal.ff9cdc66.js";import"./metadata.4547132f.js";import"./icons.a522dd78.js";import"./index.08ab98c1.js";import"./index.feab3270.js";import"./index.b25a8e2d.js";import"./index.44d09d66.js";import"./index.9e008bd7.js";import"./CollapsePanel.749a5c00.js";import"./Form.f49cd330.js";import"./FormItem.e7fba2a7.js";import"./hasIn.d73516ff.js";import"./Timeline.40643c20.js";import"./index.153faf98.js";import"./isNumeric.75337b1e.js";import"./contracts.generated.c3874a56.js";import"./index.cf4c23b9.js";import"./scripts.4a7ed91a.js";import"./record.5766e9f8.js";import"./pubsub.f74b1921.js";import"./workspaces.5f7fbba3.js";import"./runnerData.64dc3fe3.js";import"./url.f5db59c1.js";import"./ExpandOutlined.c6ee31cf.js";import"./Card.c3bad4d1.js";import"./TabPane.bad26671.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[t]="efd752a4-c556-4581-a77b-6470fa36c95b",o._sentryDebugIdIdentifier="sentry-dbid-efd752a4-c556-4581-a77b-6470fa36c95b")}catch{}})();const so=c({__name:"Kanban",setup(o){const t=new f(g),e=new l("kanban"),{result:a}=y(_);return(k,w)=>{var n,i,m;return b(),u("div",null,[p(s,{"brand-name":((n=r(a))==null?void 0:n.brandName)||((i=r(a))==null?void 0:i.name),"logo-url":(m=r(a))==null?void 0:m.logoUrl},null,8,["brand-name","logo-url"]),p(d,{"kanban-repository":r(t),storage:r(e)},null,8,["kanban-repository","storage"])])}}});export{so as default};
//# sourceMappingURL=Kanban.da5ce141.js.map
