import{V as s,f as p,Q as d}from"./outputWidgets.244ba1c8.js";import{B as f,b as c}from"./Base.2351f159.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="c1a670cf-699e-469e-8c4d-815b6b3f8713",e._sentryDebugIdIdentifier="sentry-dbid-c1a670cf-699e-469e-8c4d-815b6b3f8713")}catch{}})();const i=()=>d(c(),["component"]),a=(e,r)=>{let{slots:t,attrs:o}=r;const n=s(s(s({},e),{component:"div"}),o);return p(f,n,t)};a.displayName="ATypographyParagraph";a.inheritAttrs=!1;a.props=i();const g=a;export{g as A};
//# sourceMappingURL=Paragraph.bffb9dac.js.map
