import{d as m,eB as c,u as e,b as d,c as u,ev as y,f as a,w as o,bv as _,ar as p,ex as g,e as x,eD as b}from"./outputWidgets.244ba1c8.js";import"./router.60675eeb.js";import"./index.bec3aec1.js";import{O as w}from"./organization.77001a16.js";import{a as k}from"./asyncComputed.9805a381.js";import{A}from"./Title.eb85429e.js";import{A as B}from"./index.08ab98c1.js";import{A as h}from"./index.f8cee946.js";import{A as C}from"./Text.fbfa9a45.js";import{C as v}from"./Card.c3bad4d1.js";import"./FormItem.e7fba2a7.js";import"./hasIn.d73516ff.js";import"./index.cf4c23b9.js";import"./record.5766e9f8.js";import"./pubsub.f74b1921.js";import"./Base.2351f159.js";import"./Typography.52981f51.js";import"./TabPane.bad26671.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[r]="48111783-75a3-4d9f-a287-793c4ea6a134",t._sentryDebugIdIdentifier="sentry-dbid-48111783-75a3-4d9f-a287-793c4ea6a134")}catch{}})();const D={key:1},I={style:{display:"flex","justify-content":"flex-end","font-size":"24px"}},W=m({__name:"Billing",setup(t){const n=c().params.organizationId,{loading:l,result:f}=k(()=>w.get(n));return(z,N)=>e(l)?(d(),u(e(_),{key:0})):(d(),y("div",D,[a(e(B),{justify:"space-between",align:"center"},{default:o(()=>[a(e(A),{level:3},{default:o(()=>[p("Current plan")]),_:1}),g("",!0)]),_:1}),a(e(h),{style:{"margin-top":"0"}}),a(e(v),{style:{width:"300px"}},{default:o(()=>{var i,s;return[a(e(C),{type:"secondary"},{default:o(()=>[p("Plan")]),_:1}),x("div",I,b((s=(i=e(f))==null?void 0:i.billingMetadata)==null?void 0:s.plan),1)]}),_:1})]))}});export{W as default};
//# sourceMappingURL=Billing.244a2037.js.map
