import{N as _}from"./NavbarControls.210f1bad.js";import{d as b,eA as f,eB as y,H as g,a as v,b as c,ev as h,f as e,w as s,u as r,e as k,a$ as w,ar as S,c as x,eS as q,v as A}from"./outputWidgets.244ba1c8.js";import{A as B}from"./Text.fbfa9a45.js";import{T as C,A as o}from"./TabPane.bad26671.js";import{c as I}from"./index.29328ced.js";import"./index.cc4549b3.js";import"./pubsub.f74b1921.js";import"./asyncComputed.9805a381.js";import"./SaveButton.vue_vue_type_script_setup_true_lang.4dcb99e4.js";import"./ant-design.2b0214de.js";import"./index.d38d9f1b.js";import"./Modal.ff9cdc66.js";import"./Typography.52981f51.js";import"./Link.82df400a.js";import"./Base.2351f159.js";import"./index.6c491bc0.js";import"./workspaces.5f7fbba3.js";import"./runnerData.64dc3fe3.js";import"./url.f5db59c1.js";import"./record.5766e9f8.js";import"./popupNotifcation.66c3e9dd.js";import"./icons.a522dd78.js";import"./index.08ab98c1.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.aee5d1fe.js";import"./Paragraph.bffb9dac.js";import"./hasIn.d73516ff.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[t]="68134a84-249b-430d-95cd-6e9cec452473",a._sentryDebugIdIdentifier="sentry-dbid-68134a84-249b-430d-95cd-6e9cec452473")}catch{}})();const T={class:"content"},D=b({__name:"Settings",setup(a){const t=f(),n=y();function m(){t.push({name:"home"})}const u=g(()=>{switch(n.name){case"settingsStyle":return"style";case"settingsSidebar":return"sidebar";case"settingsRequirements":return"requirements";default:return}});function p(i){switch(i){case"style":t.push({name:"settingsStyle"});break;case"sidebar":t.push({name:"settingsSidebar"});break;case"requirements":t.push({name:"settingsRequirements"});break}}return(i,N)=>{const d=v("router-view");return c(),h(w,null,[e(r(I),{style:{padding:"5px 25px"},onBack:m},{extra:s(()=>[e(_,{"show-v-s-code-button":"","show-save-button":""})]),avatar:s(()=>[e(r(B),null,{default:s(()=>[S("Settings")]),_:1})]),footer:s(()=>[e(r(C),{"active-key":u.value,onChange:p},{default:s(()=>[e(r(o),{key:"style",tab:"Style"}),e(r(o),{key:"sidebar",tab:"Sidebar"}),e(r(o),{key:"requirements",tab:"Requirements"})]),_:1},8,["active-key"])]),_:1}),k("div",T,[e(d,null,{default:s(({Component:l})=>[(c(),x(q(l)))]),_:1})])],64)}}});const oe=A(D,[["__scopeId","data-v-772f4b10"]]);export{oe as default};
//# sourceMappingURL=Settings.32ceacd3.js.map
