import{f as u,eG as i,d as f,b as s,c as p,w as c,u as l,dp as b,ev as m,ar as g,a$ as h,bV as y}from"./outputWidgets.244ba1c8.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="7ae8c3fd-67c1-48da-af21-57e3ca5bed3e",t._sentryDebugIdIdentifier="sentry-dbid-7ae8c3fd-67c1-48da-af21-57e3ca5bed3e")}catch{}})();var v={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M832 64H192c-17.7 0-32 14.3-32 32v832c0 17.7 14.3 32 32 32h640c17.7 0 32-14.3 32-32V96c0-17.7-14.3-32-32-32zm-260 72h96v209.9L621.5 312 572 347.4V136zm220 752H232V136h280v296.9c0 3.3 1 6.6 3 9.3a15.9 15.9 0 0022.3 3.7l83.8-59.9 81.4 59.4c2.7 2 6 3.1 9.4 3.1 8.8 0 16-7.2 16-16V136h64v752z"}}]},name:"book",theme:"outlined"};const O=v;function d(t){for(var e=1;e<arguments.length;e++){var n=arguments[e]!=null?Object(arguments[e]):{},a=Object.keys(n);typeof Object.getOwnPropertySymbols=="function"&&(a=a.concat(Object.getOwnPropertySymbols(n).filter(function(r){return Object.getOwnPropertyDescriptor(n,r).enumerable}))),a.forEach(function(r){_(t,r,n[r])})}return t}function _(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var o=function(e,n){var a=d({},e,n.attrs);return u(i,d({},a,{icon:O}),null)};o.displayName="BookOutlined";o.inheritAttrs=!1;const k=o,w=f({__name:"DocsButton",props:{path:{}},setup(t){return(e,n)=>{var a;return s(),p(l(y),{class:"docs-button",href:`https://docs.abstra.io/${(a=e.path)!=null?a:""}`,target:"_blank",type:"link",size:"small"},{icon:c(()=>[u(l(k))]),default:c(()=>[e.$slots.default?b(e.$slots,"default",{key:0}):(s(),m(h,{key:1},[g("Docs")],64))]),_:3},8,["href"])}}});export{w as _};
//# sourceMappingURL=DocsButton.vue_vue_type_script_setup_true_lang.aee5d1fe.js.map
