import{z as e}from"./index.cf4c23b9.js";import"./outputWidgets.244ba1c8.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[a]="b9f8efec-1cc7-4d1a-988f-b162148b636c",t._sentryDebugIdIdentifier="sentry-dbid-b9f8efec-1cc7-4d1a-988f-b162148b636c")}catch{}})();const g=e.boolean(),S=e.boolean(),b=e.boolean(),C=e.boolean();e.object({PROJECT_LIVE:g.optional(),ALLOW_RELEASE:S.optional(),CONNECTORS_CONSOLE:b.optional(),DUPLICATE_PROJECTS:C.optional()});const u=e.string();e.object({plan:u.optional()});const h=e.string(),d=e.string(),A=e.string(),R=e.string(),L=e.string().regex(new RegExp("^[0-9]+m$")),y=e.string().regex(new RegExp("^[0-9]+m$")),O=e.string().regex(new RegExp("^[0-9]+Mi$")),P=e.string().regex(new RegExp("^[0-9]+Mi$")),E=e.string().regex(new RegExp("^[0-9]+$")),x=e.string().regex(new RegExp("^[0-9]+$")),j=e.enum(["shared","clickbus","test"]),M=e.object({requestsCPU:L.optional(),limitsCPU:y.optional(),requestsMemory:O.optional(),limitsMemory:P.optional(),minReplicas:E.optional(),timeoutSeconds:x.optional(),workerType:j.optional()});e.object({id:h,name:d,subdomain:A,organizationId:R,deploymentResources:M.optional()});const w=e.string().regex(new RegExp("^[0-9]+m$")),I=e.string().regex(new RegExp("^[0-9]+m$")),D=e.string().regex(new RegExp("^[0-9]+Mi$")),z=e.string().regex(new RegExp("^[0-9]+Mi$")),U=e.string().regex(new RegExp("^[0-9]+$")),f=e.string().regex(new RegExp("^[0-9]+$")),T=e.enum(["shared","clickbus","test"]);e.object({requestsCPU:w.optional(),limitsCPU:I.optional(),requestsMemory:D.optional(),limitsMemory:z.optional(),minReplicas:U.optional(),timeoutSeconds:f.optional(),workerType:T.optional()});const _=e.string(),n=e.string(),F=e.literal("workflow_viewer"),mt=["workflow_viewer"],o=e.array(F),N=e.string(),q=e.string(),$=e.object({id:_,email:n,roles:o,projectId:N,createdAt:q}),s=e.string(),i=e.string(),k=e.boolean(),V=e.boolean(),W=e.boolean(),K=e.boolean(),r=e.object({PROJECT_LIVE:k,ALLOW_RELEASE:V,CONNECTORS_CONSOLE:W,DUPLICATE_PROJECTS:K}),J=e.string(),m=e.object({plan:J.optional()}),B=e.string().regex(new RegExp("^[0-9]+m$")),v=e.string().regex(new RegExp("^[0-9]+m$")),G=e.string().regex(new RegExp("^[0-9]+Mi$")),Q=e.string().regex(new RegExp("^[0-9]+Mi$")),H=e.string().regex(new RegExp("^[0-9]+$")),X=e.string().regex(new RegExp("^[0-9]+$")),Y=e.enum(["shared","clickbus","test"]),Z=e.object({requestsCPU:B.optional(),limitsCPU:v.optional(),requestsMemory:G.optional(),limitsMemory:Q.optional(),minReplicas:H.optional(),timeoutSeconds:X.optional(),workerType:Y.optional()}),ee=e.string(),te=e.array(ee),oe=e.object({whitelistPatterns:te.optional()});e.object({id:s,name:i,featureFlags:r,billingMetadata:m,deploymentResources:Z.optional(),membershipsMetadata:oe.optional()});const ae=e.string(),ne=e.array(ae);e.object({whitelistPatterns:ne.optional()});const se=s,ie=i,re=r,me=m;e.object({id:se,name:ie,featureFlags:re,billingMetadata:me});const ce=o;e.object({roles:ce});const le=e.number(),pe=e.number();e.object({offset:le.optional(),limit:pe.optional()});const ge=$;e.array(ge);const Se=n,be=o;e.object({email:Se,roles:be});const Ce=e.boolean();e.object({shouldBeOnboarded:Ce.optional()});const ue=e.string(),he=e.string(),de=e.string(),Ae=e.string();e.object({name:ue.optional(),companyName:he.optional(),source:de.optional(),authorEmail:Ae.optional()});const Re=e.string(),Le=e.record(e.any()),ye=e.string(),Oe=e.object({key:Re,value:Le,type:ye}),Pe=Oe,Ee=e.array(Pe),xe=e.string(),je=e.enum(["text","image","table","progress-bar"]),Me=e.object({name:xe,type:je}),we=e.string(),Ie=e.string(),De=e.record(e.any()),c=e.enum(["waiting","running","finished","failed","abandoned"]),ct=["waiting","running","finished","failed","abandoned"],ze=e.string(),Ue=e.string(),fe=e.string();e.object({id:we,stage:Ie,data:De,status:c,created_at:ze,parent_id:Ue.optional(),execution_id:fe.optional()});const Te=e.string(),_e=e.string(),Fe=e.string(),Ne=c,qe=Ee,$e=e.object({id:Te,created_at:_e,assignee:Fe.optional(),status:Ne,content:qe}),ke=$e,Ve=e.array(ke),We=e.string(),Ke=e.enum(["form","hook","job","script","iterator","condition"]),Je=e.string(),Be=e.string(),ve=e.boolean(),l=e.object({id:We,type:Ke,title:Je,path:Be.optional(),can_be_started:ve}),Ge=l,Qe=Ve,He=l,p=e.array(He),Xe=p,Ye=e.number(),Ze=e.object({selected_stage:Ge,stage_run_cards:Qe,stages:Xe,total_count:Ye}),et=Ze,tt=e.array(et),ot=tt,at=p;e.object({columns:ot,next_stage_options:at});const nt=Me;e.array(nt);export{ct as A,mt as C};
//# sourceMappingURL=contracts.generated.c3874a56.js.map
