import{e8 as i,ac as b,V as s,f,Q as p}from"./outputWidgets.244ba1c8.js";import{B as y,b as u}from"./Base.2351f159.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="dbdcb10a-dcf8-4de4-9d42-61c3dcbb8472",e._sentryDebugIdIdentifier="sentry-dbid-dbdcb10a-dcf8-4de4-9d42-61c3dcbb8472")}catch{}})();var g=globalThis&&globalThis.__rest||function(e,o){var n={};for(var t in e)Object.prototype.hasOwnProperty.call(e,t)&&o.indexOf(t)<0&&(n[t]=e[t]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var r=0,t=Object.getOwnPropertySymbols(e);r<t.length;r++)o.indexOf(t[r])<0&&Object.prototype.propertyIsEnumerable.call(e,t[r])&&(n[t[r]]=e[t[r]]);return n};const m=i(1,2,3,4,5),_=()=>s(s({},p(u(),["component","strong"])),{level:Number}),l=(e,o)=>{let{slots:n,attrs:t}=o;const{level:r=1}=e,d=g(e,["level"]);let a;m.includes(r)?a=`h${r}`:(b(),a="h1");const c=s(s(s({},d),{component:a}),t);return f(y,c,n)};l.displayName="ATypographyTitle";l.inheritAttrs=!1;l.props=_();const w=l;export{w as A};
//# sourceMappingURL=Title.eb85429e.js.map
