import{S as p}from"./Sidebar.1f2caf94.js";import{_ as c}from"./Navbar.vue_vue_type_script_setup_true_lang.810ea952.js";import{E as d,F as l,G as u}from"./icons.a522dd78.js";import{d as b,eB as f,H as g,a as _,b as y,c as v,w as t,f as r}from"./outputWidgets.244ba1c8.js";import{a as w}from"./asyncComputed.9805a381.js";import"./router.60675eeb.js";import"./index.bec3aec1.js";import{O as z}from"./organization.77001a16.js";import{B as h}from"./BaseLayout.8bb2298c.js";import"./index.feab3270.js";import"./logo.084e5d7c.js";import"./Text.fbfa9a45.js";import"./Base.2351f159.js";import"./Typography.52981f51.js";import"./index.29328ced.js";import"./FormItem.e7fba2a7.js";import"./hasIn.d73516ff.js";import"./index.cf4c23b9.js";import"./record.5766e9f8.js";import"./pubsub.f74b1921.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="781e0154-7537-49a2-ba71-abe7c40d1131",o._sentryDebugIdIdentifier="sentry-dbid-781e0154-7537-49a2-ba71-abe7c40d1131")}catch{}})();const J=b({__name:"Organization",setup(o){const n=f().params.organizationId,{result:a}=w(()=>z.get(n)),i=g(()=>a.value?[{label:"My organizations",path:"/organizations"},{label:a.value.name,path:`/organizations/${a.value.id}`}]:void 0),s=[{name:"Organization",items:[{name:"Projects",icon:d,path:"projects"},{name:"Members",icon:l,path:"members"},{name:"Billing",icon:u,path:"billing"}]}];return(I,B)=>{const m=_("router-view");return y(),v(h,null,{navbar:t(()=>[r(c,{breadcrumb:i.value},null,8,["breadcrumb"])]),sidebar:t(()=>[r(p,{class:"sidebar",sections:s})]),content:t(()=>[r(m)]),_:1})}}});export{J as default};
//# sourceMappingURL=Organization.9a391eae.js.map
