import{cz as n}from"./outputWidgets.244ba1c8.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="f4f9e997-9e72-48b6-818a-0803ea20d261",e._sentryDebugIdIdentifier="sentry-dbid-f4f9e997-9e72-48b6-818a-0803ea20d261")}catch{}})();const d=(e,r)=>{n.error({message:e,description:r})};export{d as p};
//# sourceMappingURL=popupNotifcation.66c3e9dd.js.map
