import"./outputWidgets.244ba1c8.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="a77812c2-7264-4c85-accb-5b4b4373f457",e._sentryDebugIdIdentifier="sentry-dbid-a77812c2-7264-4c85-accb-5b4b4373f457")}catch{}})();function i(e){return e.charAt(0).toUpperCase()+e.slice(1)}function l(e,r,t=!1,o=!0){const n=(o?e.toLocaleLowerCase():e).replace(/[^a-zA-Z0-9]/g,"_"),c=t?n:n.replace(/_+/g,"_");return r?c:c.replace(/_$/,"")}function u(e){var n;const t=e.toLocaleLowerCase().trim().normalize("NFD").replace(/[\u0300-\u036f]/g,""),o=/[a-z0-9]+/g,a=t.match(o);return(n=a==null?void 0:a.join("-"))!=null?n:""}function d(e){try{return JSON.parse(e),!0}catch{return!1}}export{u as a,i as c,l as n,d as v};
//# sourceMappingURL=string.857814ea.js.map
