import{C as t,A as m}from"./CollapsePanel.749a5c00.js";import{F as n}from"./Form.f49cd330.js";import{aM as c,co as r}from"./outputWidgets.244ba1c8.js";import{T as o,A as s}from"./Timeline.40643c20.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="c94f03fe-228d-4a20-80d5-a5f05cc39e06",e._sentryDebugIdIdentifier="sentry-dbid-c94f03fe-228d-4a20-80d5-a5f05cc39e06")}catch{}})();t.Panel=m;t.install=function(e){return e.component(t.name,t),e.component(m.name,m),e};n.useInjectFormItemContext=c;n.ItemRest=r;n.install=function(e){return e.component(n.name,n),e.component(n.Item.name,n.Item),e.component(r.name,r),e};o.Item=s;o.install=function(e){return e.component(o.name,o),e.component(s.name,s),e};
//# sourceMappingURL=index.9e008bd7.js.map
