import{B as s}from"./Base.2351f159.js";import{A as o}from"./Link.82df400a.js";import{A as a}from"./Paragraph.bffb9dac.js";import{A as r}from"./Text.fbfa9a45.js";import{A as i}from"./Title.eb85429e.js";import{T as e}from"./Typography.52981f51.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[t]="82534b2b-c037-43a3-bffa-9c6bebb9269b",n._sentryDebugIdIdentifier="sentry-dbid-82534b2b-c037-43a3-bffa-9c6bebb9269b")}catch{}})();e.Text=r;e.Title=i;e.Paragraph=a;e.Link=o;e.Base=s;e.install=function(n){return n.component(e.name,e),n.component(e.Text.displayName,r),n.component(e.Title.displayName,i),n.component(e.Paragraph.displayName,a),n.component(e.Link.displayName,o),n};
//# sourceMappingURL=index.e7c19b0b.js.map
