import{g as c}from"./api.438fac86.js";import{P as m}from"./Passwordless.ede28e9e.js";import{a as p}from"./asyncComputed.9805a381.js";import{W as u}from"./WidgetsFrame.e7652a72.js";import{d as f,eA as l,eB as _,b as d,ev as y,e as g,u as a,c as b,w as h,ex as w,f as v,v as k}from"./outputWidgets.244ba1c8.js";import"./runnerData.64dc3fe3.js";import"./url.f5db59c1.js";import"./index.cc4549b3.js";import"./pubsub.f74b1921.js";import"./icons.a522dd78.js";import"./CircularLoading.eff52010.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="017e1318-ecaa-4c16-8da6-e5eeab6298f1",e._sentryDebugIdIdentifier="sentry-dbid-017e1318-ecaa-4c16-8da6-e5eeab6298f1")}catch{}})();const x={class:"login"},I=f({__name:"Login",setup(e){const t=l(),s=_(),{result:o}=p(c),i=()=>{const{redirect:r,...n}=s.query;if(r){t.push({path:r,query:n,params:s.params});return}t.push({name:"playerKanban",query:n})};return(r,n)=>(d(),y("div",null,[g("div",x,[a(o)?(d(),b(u,{key:0,"main-color":a(o).mainColor,theme:a(o).theme,"font-family":a(o).fontFamily,style:{width:"100vw"}},{default:h(()=>[v(m,{onDone:i})]),_:1},8,["main-color","theme","font-family"])):w("",!0)])]))}});const R=k(I,[["__scopeId","data-v-33714d9d"]]);export{R as default};
//# sourceMappingURL=Login.3ef3385b.js.map
