import{K as n,E as p,L as a}from"./repository.116bfb52.js";import{d as s,b as m,c as d,u as e}from"./outputWidgets.244ba1c8.js";import{l as c}from"./index.cc4549b3.js";import"./ant-design.2b0214de.js";import"./index.d38d9f1b.js";import"./Modal.ff9cdc66.js";import"./asyncComputed.9805a381.js";import"./metadata.4547132f.js";import"./icons.a522dd78.js";import"./index.08ab98c1.js";import"./index.feab3270.js";import"./index.b25a8e2d.js";import"./Paragraph.bffb9dac.js";import"./Base.2351f159.js";import"./Typography.52981f51.js";import"./index.e7c19b0b.js";import"./Link.82df400a.js";import"./Text.fbfa9a45.js";import"./Title.eb85429e.js";import"./index.44d09d66.js";import"./index.9e008bd7.js";import"./CollapsePanel.749a5c00.js";import"./Form.f49cd330.js";import"./FormItem.e7fba2a7.js";import"./hasIn.d73516ff.js";import"./Timeline.40643c20.js";import"./index.153faf98.js";import"./isNumeric.75337b1e.js";import"./contracts.generated.c3874a56.js";import"./index.cf4c23b9.js";import"./scripts.4a7ed91a.js";import"./record.5766e9f8.js";import"./pubsub.f74b1921.js";import"./workspaces.5f7fbba3.js";import"./runnerData.64dc3fe3.js";import"./url.f5db59c1.js";import"./ExpandOutlined.c6ee31cf.js";import"./Card.c3bad4d1.js";import"./TabPane.bad26671.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[o]="c21f1a30-f718-4542-addb-7455216b1a4d",t._sentryDebugIdIdentifier="sentry-dbid-c21f1a30-f718-4542-addb-7455216b1a4d")}catch{}})();class f{constructor(o=c){this.fetch=o}async fork(o){return(await this.fetch("/_editor/api/stage_runs/fork",{method:"POST",body:JSON.stringify({stage_run_id:o}),headers:{"Content-Type":"application/json"}})).json()}}const oo=s({__name:"WorkflowKanban",setup(t){const o=new p,r=new f,i=new a("kanban");return(u,b)=>(m(),d(n,{"kanban-repository":e(o),storage:e(i),"stage-run-repository":e(r)},null,8,["kanban-repository","storage","stage-run-repository"]))}});export{oo as default};
//# sourceMappingURL=WorkflowKanban.1c9e92dd.js.map
