import{r as n,w as r}from"./runnerData.64dc3fe3.js";import"./outputWidgets.244ba1c8.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="a6097a41-f47a-43be-8154-a557d999783c",t._sentryDebugIdIdentifier="sentry-dbid-a6097a41-f47a-43be-8154-a557d999783c")}catch{}})();async function f(t){const e=await fetch(`/_pages/${t}`);if(e.status==404)return null;if(!e.ok)throw new Error(await e.text());const{form:a}=await e.json();return{form:a&&n(a)}}async function i(){const t=await fetch("/_workspace");if(t.status!=200)return r({});const e=await t.json();return r(e)}export{f as a,i as g};
//# sourceMappingURL=api.438fac86.js.map
