import{eV as t,eW as r}from"./outputWidgets.244ba1c8.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="ae67c049-e766-44f1-af49-8f41e140b48c",e._sentryDebugIdIdentifier="sentry-dbid-ae67c049-e766-44f1-af49-8f41e140b48c")}catch{}})();function o(e,n){return t(1,arguments),r(e,Date.now(),n)}export{o as f};
//# sourceMappingURL=index.b25a8e2d.js.map
