import{d as h,eA as w,eB as k,r as x,H as y,b as n,c as l,w as t,ev as b,eC as I,u as d,bu as C,ez as f,f as s,I as B,ar as N,eD as D,a$ as S,bw as V,v as A,eE as E,eF as L,e as g,a as p,ex as T}from"./outputWidgets.244ba1c8.js";import{h as $,s as H}from"./icons.a522dd78.js";import{_ as z}from"./logo.084e5d7c.js";import{B as F}from"./BaseLayout.8bb2298c.js";import{N as M}from"./NavbarControls.210f1bad.js";import{c as R}from"./index.29328ced.js";import"./index.cc4549b3.js";import"./pubsub.f74b1921.js";import"./asyncComputed.9805a381.js";import"./SaveButton.vue_vue_type_script_setup_true_lang.4dcb99e4.js";import"./ant-design.2b0214de.js";import"./index.d38d9f1b.js";import"./Modal.ff9cdc66.js";import"./Typography.52981f51.js";import"./Link.82df400a.js";import"./Base.2351f159.js";import"./index.6c491bc0.js";import"./workspaces.5f7fbba3.js";import"./runnerData.64dc3fe3.js";import"./url.f5db59c1.js";import"./record.5766e9f8.js";import"./popupNotifcation.66c3e9dd.js";import"./index.08ab98c1.js";import"./Text.fbfa9a45.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.aee5d1fe.js";import"./Paragraph.bffb9dac.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="d45c14f9-6ff6-4715-9662-b712f745342c",e._sentryDebugIdIdentifier="sentry-dbid-d45c14f9-6ff6-4715-9662-b712f745342c")}catch{}})();const W=h({__name:"Sidebar",setup(e){var m;const o=w(),c=k(),r=x((m=c.name)!=null?m:"forms"),u=y(()=>[{name:"Home",icon:$,path:"home"},{name:"Settings",icon:H,path:"settings"}]),i=_=>{o.push(_.path),r.value=_.path};return(_,Q)=>(n(),l(d(V),{"inline-collapsed":""},{default:t(()=>[(n(!0),b(S,null,I(u.value,a=>(n(),l(d(C),{key:a.name,role:"button",class:f({active:r.value===a.path}),tabindex:"0",onClick:U=>i(a)},{icon:t(()=>[s(B,{class:f({active:r.value===a.path}),path:a.icon,width:"20",height:"20"},null,8,["class","path"])]),title:t(()=>[N(D(a.name),1)]),_:2},1032,["class","onClick"]))),128))]),_:1}))}});const P={},v=e=>(E("data-v-81cd596e"),e=e(),L(),e),j={class:"logo"},q=v(()=>g("img",{src:z,alt:"Abstra cloud logo"},null,-1)),G=v(()=>g("span",null," Abstra ",-1)),J=[q,G];function K(e,o){return n(),b("div",j,J)}const O=A(P,[["render",K],["__scopeId","data-v-81cd596e"]]),ye=h({__name:"Workspace",setup(e){return(o,c)=>{const r=p("ant-button"),u=p("router-link"),i=p("router-view");return n(),l(F,null,{navbar:t(()=>[s(d(R),{style:{padding:"5px 25px"}},{title:t(()=>[s(O)]),extra:t(()=>[s(M,{"show-github-stars":""},{default:t(()=>[T("",!0)]),_:1})]),_:1})]),sidebar:t(()=>[s(W,{class:"sidebar"})]),content:t(()=>[s(i)]),_:1})}}});export{ye as default};
//# sourceMappingURL=Workspace.daadf11a.js.map
