import{g as b}from"./api.438fac86.js";import{a as v}from"./asyncComputed.9805a381.js";import{d as h,eA as k,H as x,b as t,ev as d,u as e,c as p,w as s,ex as w,ar as u,a$ as C,eC as I,f as l,eD as D,I as T,v as B}from"./outputWidgets.244ba1c8.js";import{e as H}from"./icons.a522dd78.js";import"./index.e7c19b0b.js";import"./index.a16eaa54.js";import{A as m}from"./index.08ab98c1.js";import{T as f}from"./Typography.52981f51.js";import{C as A}from"./Card.c3bad4d1.js";import"./runnerData.64dc3fe3.js";import"./url.f5db59c1.js";import"./Base.2351f159.js";import"./Link.82df400a.js";import"./Paragraph.bffb9dac.js";import"./Text.fbfa9a45.js";import"./Title.eb85429e.js";import"./TabPane.bad26671.js";import"./hasIn.d73516ff.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[n]="1363bd96-ad1e-4013-827d-f66eaf49dc15",a._sentryDebugIdIdentifier="sentry-dbid-1363bd96-ad1e-4013-827d-f66eaf49dc15")}catch{}})();const F={class:"container"},N={key:0},V=h({__name:"Home",setup(a){const n=k(),{result:c,loading:y}=v(b),_=x(()=>{var o,i;return(i=(o=c.value)==null?void 0:o.sidebar.filter(r=>r.visible))!=null?i:[]}),g=o=>{n.push({path:`/${o}`})};return(o,i)=>(t(),d("div",F,[e(y)?(t(),d("span",N,"...")):_.value.length===0?(t(),p(e(f),{key:1,type:"secondary"},{default:s(()=>[u(" There are no public forms available ")]),_:1})):(t(),p(e(m),{key:2,vertical:"",gap:"large",style:{padding:"120px 40px"}},{default:s(()=>[(t(!0),d(C,null,I(_.value,r=>(t(),p(e(A),{key:r.id,class:"form-card",onClick:$=>g(r.path)},{default:s(()=>[l(e(m),{gap:"large",align:"center",justify:"space-between"},{default:s(()=>[l(e(f),{style:{"font-size":"18px","font-weight":"500"}},{default:s(()=>[u(D(r.name),1)]),_:2},1024),l(T,{path:e(H),fill:"#000",width:"20"},null,8,["path"])]),_:2},1024)]),_:2},1032,["onClick"]))),128))]),_:1})),w("",!0)]))}});const Z=B(V,[["__scopeId","data-v-5eb82e4e"]]);export{Z as default};
//# sourceMappingURL=Home.eb601cd2.js.map
