import"./outputWidgets.244ba1c8.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="8c5084aa-4bc4-4a86-a613-e19c30cd87c0",e._sentryDebugIdIdentifier="sentry-dbid-8c5084aa-4bc4-4a86-a613-e19c30cd87c0")}catch{}})();const c=e=>{try{return new URL(e),!0}catch{return!1}};export{c as i};
//# sourceMappingURL=url.f5db59c1.js.map
