import{v as a,a as r,b as i,c,j as d,T as p,k as _,P as u,C as b,M as f,s as l,l as s,m as g,n as m,p as y,q as v}from"./outputWidgets.244ba1c8.js";import{s as w,a as o}from"./index.cc4549b3.js";import"./pubsub.f74b1921.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="380b8a4d-25cc-42b8-9d55-8b9bad84a9ce",e._sentryDebugIdIdentifier="sentry-dbid-380b8a4d-25cc-42b8-9d55-8b9bad84a9ce")}catch{}})();const h={};function I(e,t){const n=r("router-view");return i(),c(n,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const k=a(h,[["render",I]]);class x{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await w();const e=d({render:()=>g(k)});p.init(),_(e,o),x.init(),e.use(o),e.use(u),e.mount("#app"),e.component("VSelect",b),e.component("Markdown",f),e.component("Message",l),s(e,m),s(e,y),s(e,v)})();
//# sourceMappingURL=player.a60eeb0a.js.map
