import{ac as p,V as t,Q as r,f as l}from"./outputWidgets.244ba1c8.js";import{B as c,b as f}from"./Base.2351f159.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="7bea9a07-4934-4ad8-82a5-079e7358b88c",e._sentryDebugIdIdentifier="sentry-dbid-7bea9a07-4934-4ad8-82a5-079e7358b88c")}catch{}})();const b=()=>t(t({},r(f(),["component"])),{ellipsis:{type:[Boolean,Object],default:void 0}}),a=(e,s)=>{let{slots:o,attrs:d}=s;const{ellipsis:n}=e;p();const i=t(t(t({},e),{ellipsis:n&&typeof n=="object"?r(n,["expandable","rows"]):n,component:"span"}),d);return l(c,i,o)};a.displayName="ATypographyText";a.inheritAttrs=!1;a.props=b();const g=a;export{g as A};
//# sourceMappingURL=Text.fbfa9a45.js.map
