import{d as b,eB as f,eA as C,H as g,b as _,c as I,u as h}from"./outputWidgets.244ba1c8.js";import{b as w}from"./index.bec3aec1.js";import"./router.60675eeb.js";import{C as i}from"./connector.09fd5ca7.js";import{a as k}from"./asyncComputed.9805a381.js";import{q as x,d as E}from"./icons.a522dd78.js";import{C as D}from"./CrudView.47ed1f4a.js";import"./index.cf4c23b9.js";import"./record.5766e9f8.js";import"./pubsub.f74b1921.js";import"./FormItem.e7fba2a7.js";import"./hasIn.d73516ff.js";import"./Paragraph.bffb9dac.js";import"./Base.2351f159.js";import"./Typography.52981f51.js";import"./Form.f49cd330.js";import"./Modal.ff9cdc66.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.aee5d1fe.js";import"./url.f5db59c1.js";import"./index.08ab98c1.js";import"./Title.eb85429e.js";import"./Text.fbfa9a45.js";import"./index.feab3270.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="31e83bdc-0502-44d0-9394-b47bb65c8aad",o._sentryDebugIdIdentifier="sentry-dbid-31e83bdc-0502-44d0-9394-b47bb65c8aad")}catch{}})();const W=b({__name:"Connectors",setup(o){const r=f(),a=C(),c=r.params.projectId;async function s(e){const t=await i.create(c,e.name,e.type);a.push({name:"connectorEditor",params:{connectorId:t.id}})}const p=[{key:"name",label:"Connector name",type:"text"},{key:"type",label:"Connector type",type:Object.entries(w.schema).map(([e,t])=>({value:e,label:t.label}))}],{loading:m,result:d,refetch:l}=k(()=>i.list(c)),u=g(()=>{var e,t;return{columns:[{name:"Name"},{name:"Type"},{name:"",align:"right"}],rows:(t=(e=d.value)==null?void 0:e.map(n=>({key:n.id,cells:[{type:"link",text:n.name,to:{name:"connectorEditor",params:{connectorId:n.id}}},{type:"text",text:n.type},{type:"actions",actions:[{icon:x,label:"Edit",onClick({key:y}){a.push({name:"connectorEditor",params:{connectorId:y}})}},{icon:E,label:"Delete",dangerous:!0,async onClick(){await n.delete(),l()}}]}]})))!=null?t:[]}});return(e,t)=>(_(),I(D,{"entity-name":"connector",loading:h(m),title:"Connectors",description:"Each connector is a version of your app. You can create a new connector by deploying your app from the local editor.","empty-title":"No connectors here yet",table:u.value,fields:p,"create-button-text":"Create connector",onCreate:s},null,8,["loading","table"]))}});export{W as default};
//# sourceMappingURL=Connectors.17f3a55d.js.map
